NegateY

Trait NegateY 

pub(crate) trait NegateY {
    // Required method
    fn negate_y(&self) -> Self;
}
This trait is used to negate the Y coordinate of the group commitment element with FROST This is achieved by negating all nonces and commitments produced by all participants

Required Methods

fn negate_y(&self) -> Self

Negate the Y coordinate of the group element

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<M> NegateY for SigningCommitments<BluePallas<M>>

Negate the Y coordinate of the group commitment element with FROST

Source

fn negate_y(&self) -> Self

Source

impl<M> NegateY for SigningNonces<BluePallas<M>>

Source

fn negate_y(&self) -> Self

Source

impl<M> NegateY for SigningPackage<BluePallas<M>>

Take all commitments with a signing package and negate their Y coordinates

Source

fn negate_y(&self) -> Self

Implementors