pub(crate) trait NegateY {
// Required method
fn negate_y(&self) -> Self;
}Expand description
This trait is used to negate the Y coordinate of the group commitment element with FROST This is achieved by negating all nonces and commitments produced by all participants
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<M> NegateY for SigningCommitments<BluePallas<M>>where
M: ChallengeMessage,
Negate the Y coordinate of the group commitment element with FROST
impl<M> NegateY for SigningCommitments<BluePallas<M>>where
M: ChallengeMessage,
Negate the Y coordinate of the group commitment element with FROST
Sourceimpl<M> NegateY for SigningNonces<BluePallas<M>>where
M: ChallengeMessage,
impl<M> NegateY for SigningNonces<BluePallas<M>>where
M: ChallengeMessage,
Sourceimpl<M> NegateY for SigningPackage<BluePallas<M>>where
M: ChallengeMessage,
Take all commitments with a signing package and negate their Y coordinates
impl<M> NegateY for SigningPackage<BluePallas<M>>where
M: ChallengeMessage,
Take all commitments with a signing package and negate their Y coordinates